@@ -9,7 +9,7 @@ use vars qw($VERSION);
 
 # Initialize our version
 # $Revision: 1181 $
-$VERSION = '1.42';
+$VERSION = '1.44';
 
 # Import what we need from the POE namespace
 use POE;
@@ -57,7 +57,7 @@ sub new {
 	$opt{uc $_} = delete $opt{$_} for keys %opt; # Fix that pesky uppercase option stuff.
 
 	# Our own options
-	my ( $ALIAS, $ADDRESS, $PORT, $HOSTNAME, $HEADERS, $HANDLERS, $SSLKEYCERT, $LOGHANDLER, $ERRORHANDLER, $SETUPHANDLER );
+	my ( $ALIAS, $ADDRESS, $PORT, $HOSTNAME, $HEADERS, $HANDLERS, $SSLKEYCERT, $LOGHANDLER, $ERRORHANDLER, $SETUPHANDLER, $LOG2HANDLER, $PROXYMODE );
 
 	# You could say I should do this: $Stuff = delete $opt{'Stuff'}
 	# But, that kind of behavior is not defined, so I would not trust it...
@@ -71,7 +71,7 @@ sub new {
 
 			# Okay, pull in what is necessary
 			eval {
-				require POE::Component::SSLify; 
+				require POE::Component::SSLify;
 				import POE::Component::SSLify qw( SSLify_Options SSLify_GetSocket Server_SSLify SSLify_GetCipher );
 				SSLify_Options( @$SSLKEYCERT );
 			};
@@ -171,9 +171,9 @@ sub new {
 		# Make sure it is ref to an hash
 		if ( ref $opt{'ERRORHANDLER'} and ref( $opt{'ERRORHANDLER'} ) eq 'HASH' ) {
 			$ERRORHANDLER = delete $opt{'ERRORHANDLER'};
-			croak( 'ERRORHANDLER does not have a SESSION attribute' ) 
+			croak( 'ERRORHANDLER does not have a SESSION attribute' )
 			  unless $ERRORHANDLER->{'SESSION'};
-			croak( 'ERRORHANDLER does not have an EVENT attribute' ) 
+			croak( 'ERRORHANDLER does not have an EVENT attribute' )
 			  unless $ERRORHANDLER->{'EVENT'};
 		} else {
 			croak( 'ERRORHANDLER must be a reference to an HASH!' );
@@ -183,9 +183,9 @@ sub new {
 	if ( exists $opt{'LOGHANDLER'} and defined $opt{'LOGHANDLER'} ) {
 		if ( ref $opt{'LOGHANDLER'} and ref $opt{'LOGHANDLER'} eq 'HASH' ) {
 			$LOGHANDLER = delete $opt{'LOGHANDLER'};
-			croak( 'LOGHANDLER does not have a SESSION attribute' ) 
+			croak( 'LOGHANDLER does not have a SESSION attribute' )
 			  unless $LOGHANDLER->{'SESSION'};
-			croak( 'LOGHANDLER does not have an EVENT attribute' ) 
+			croak( 'LOGHANDLER does not have an EVENT attribute' )
 			  unless $LOGHANDLER->{'EVENT'};
 		}
 		else {
@@ -193,18 +193,33 @@ sub new {
 		}
 	}
 
+	if ( exists $opt{'LOG2HANDLER'} and defined $opt{'LOG2HANDLER'} ) {
+		if ( ref $opt{'LOG2HANDLER'} and ref $opt{'LOG2HANDLER'} eq 'HASH' ) {
+			$LOG2HANDLER = delete $opt{'LOG2HANDLER'};
+			croak( 'LOG2HANDLER does not have a SESSION attribute' )
+			  unless $LOG2HANDLER->{'SESSION'};
+			croak( 'LOG2HANDLER does not have an EVENT attribute' )
+			  unless $LOG2HANDLER->{'EVENT'};
+		}
+		else {
+			croak( 'LOG2HANDLER must be a reference to an HASH!' );
+		}
+	}
+
 	if ( exists $opt{'SETUPHANDLER'} and defined $opt{'SETUPHANDLER'} ) {
 		if ( ref $opt{'SETUPHANDLER'} and ref $opt{'SETUPHANDLER'} eq 'HASH' ) {
 			$SETUPHANDLER = delete $opt{'SETUPHANDLER'};
-			croak( 'SETUPHANDLER does not have a SESSION attribute' ) 
+			croak( 'SETUPHANDLER does not have a SESSION attribute' )
 			  unless $SETUPHANDLER->{'SESSION'};
-			croak( 'SETUPHANDLER does not have an EVENT attribute' ) 
+			croak( 'SETUPHANDLER does not have an EVENT attribute' )
 			  unless $SETUPHANDLER->{'EVENT'};
 		}
 		else {
 			croak( 'SETUPHANDLER must be a reference to an HASH!' );
 		}
 	}
+	
+	$PROXYMODE = $opt{'PROXYMODE'};
 
     my $KEEPALIVE = 0;
     if ( exists $opt{'KEEPALIVE'} ) {
@@ -217,8 +232,8 @@ sub new {
 			croak( 'Unrecognized options were present in POE::Component::Server::SimpleHTTP->new -> ' . join( ', ', keys %opt ) );
 		}
 	}
-	
-	my $data = { 
+
+	my $data = {
 			'ALIAS'		   =>	$ALIAS,
 			'ADDRESS'	   =>	$ADDRESS,
 			'PORT'		   =>	$PORT,
@@ -229,8 +244,10 @@ sub new {
 			'RETRIES'	   =>	0,
 			'SSLKEYCERT'   =>	$SSLKEYCERT,
 			'LOGHANDLER'   =>	$LOGHANDLER,
+			'LOG2HANDLER'   =>	$LOG2HANDLER,
 			'SETUPHANDLER' =>	$SETUPHANDLER,
 			'ERRORHANDLER' =>	$ERRORHANDLER,
+			'PROXYMODE' => 		$PROXYMODE,
             'KEEPALIVE'    =>   $KEEPALIVE
 	};
 
@@ -244,7 +261,7 @@ sub new {
 			'_start'	=>	\&StartServer,
 			'_stop'		=>	\&FindRequestLeaks,
 			'_child'	=>	sub {},
-			
+
 		   # Register states
 		   'REGISTER' => \&Register,
 
@@ -267,7 +284,7 @@ sub new {
 
 			# Send output to connection!
 			'DONE'		=>	\&Request_Output,
-			
+
 			# Stream output to connection!
 			'STREAM'	   =>	\&Stream_Output,
 
@@ -370,7 +387,7 @@ sub StopServer {
         foreach my $conn ( keys %$S ) {
     		# Can't call method "shutdown_input" on an undefined value at
 	    	# /usr/lib/perl5/site_perl/5.8.2/POE/Component/Server/SimpleHTTP.pm line 323.
-		    if ( defined $S->{ $conn }->[0] and 
+		    if ( defined $S->{ $conn }->[0] and
                     defined $S->{ $conn }->[0]->[ POE::Wheel::ReadWrite::HANDLE_INPUT ] ) {
     			$S->{ $conn }->[0]->shutdown_input;
 	    		$S->{ $conn }->[0]->shutdown_output;
@@ -379,11 +396,11 @@ sub StopServer {
 		    delete $S->{ $conn };
 	    }
     }
-    
+
 
 	# Delete our alias
 	$_[KERNEL]->alias_remove( $_[HEAP]->{'ALIAS'} ) if $_[HEAP]->{'ALIAS'};
-	$_[KERNEL]->refcount_decrement( $_[HEAP]->{'SESSION_ID'}, __PACKAGE__ ) 
+	$_[KERNEL]->refcount_decrement( $_[HEAP]->{'SESSION_ID'}, __PACKAGE__ )
 		unless $_[HEAP]->{'ALIAS'};
 
 	# Debug stuff
@@ -533,7 +550,7 @@ sub MassageHandlers {
 		# Must be ref to hash
 		if ( ref $handler->[ $count ] and ref( $handler->[ $count ] ) eq 'HASH' ) {
 			# Make sure all the keys are uppercase
-			$handler->[ $count ]->{uc $_} = delete $handler->[ $count ]->{$_} 
+			$handler->[ $count ]->{uc $_} = delete $handler->[ $count ]->{$_}
 				for keys %{ $handler->[ $count ] };
 			# Make sure it got the 3 parts necessary
 			if ( ! exists $handler->[ $count ]->{'SESSION'} or ! defined $handler->[ $count ]->{'SESSION'} ) {
@@ -602,7 +619,7 @@ sub Got_Connection {
 
     if( DEBUG and keys %{ $_[HEAP]->{CONNECTIONS} } ) {
         # use Data::Dumper;
-        warn "conn id=", $wheel->ID, " [", 
+        warn "conn id=", $wheel->ID, " [",
             join( ', ', keys %{ $_[HEAP]->{CONNECTIONS} }), "]";
     }
 
@@ -657,11 +674,11 @@ sub Got_Input {
 	# Directly access POE::Wheel::ReadWrite's HANDLE_INPUT -> to get the socket itself
 	# Hmm, if we are SSL, then have to do an extra step!
 	elsif( defined $_[HEAP]->{'SSLKEYCERT'} ) {
-		$connection = 
+		$connection =
 			POE::Component::Server::SimpleHTTP::Connection->new( SSLify_GetSocket( $_[HEAP]->{'REQUESTS'}->{ $id }->[0]->[ POE::Wheel::ReadWrite::HANDLE_INPUT ] ) );
 	}
 	else {
-		$connection = 
+		$connection =
 			POE::Component::Server::SimpleHTTP::Connection->new( $_[HEAP]->{'REQUESTS'}->{ $id }->[0]->[ POE::Wheel::ReadWrite::HANDLE_INPUT ] );
 	}
 
@@ -677,7 +694,7 @@ sub Got_Input {
 		# Make the request nothing
 		$response = $request;
 		$request = undef;
-		
+
 		# Mark that this is a malformed request
 		$malformed_req = 1;
 
@@ -690,17 +707,19 @@ sub Got_Input {
 		# Set the path to an empty string
 		$path = '';
 	} else {
-		# Add stuff it needs!
-		my $uri = $request->uri;
-		$uri->scheme( 'http' );
-		$uri->host( $_[HEAP]->{'HOSTNAME'} );
-		$uri->port( $_[HEAP]->{'PORT'} );
+		unless ( $_[HEAP]->{'PROXYMODE'} ) {
+			# Add stuff it needs!
+			my $uri = $request->uri;
+			$uri->scheme( 'http' );
+			$uri->host( $_[HEAP]->{'HOSTNAME'} );
+			$uri->port( $_[HEAP]->{'PORT'} );
 
-		# Get the path
-		$path = $uri->path();
-		if ( ! defined $path or $path eq '' ) {
-			# Make it the default handler
-			$path = '/';
+			# Get the path
+			$path = $uri->path();
+			if ( ! defined $path or $path eq '' ) {
+				# Make it the default handler
+				$path = '/';
+			}
 		}
 
 		# Get the response
@@ -752,7 +771,7 @@ sub Got_Input {
 	   $request,
 	   $response->connection->remote_ip(),
 	) if $_[HEAP]->{'LOGHANDLER'};
-	
+
 	# Warn if we had a problem dispatching to the log handler above
 	warn("I had a problem posting to event '",
 	     $_[HEAP]->{'LOGHANDLER'}->{'EVENT'},
@@ -760,15 +779,15 @@ sub Got_Input {
 	     $_[HEAP]->{'LOGHANDLE'}->{'SESSION'},
           "'. As reported by Kernel: '$!', perhaps the alias is spelled incorrectly for this handler?")
         if $!;
-	
-	
+
+
 	# If we received a malformed request then
 	# let's not try to dispatch to a handler
 	if( $malformed_req ) {
 		# Just push out the response we got from POE::Filter::HTTPD saying your request was bad
-		POE::Kernel->post( 
-			$_[HEAP]->{ERRORHANDLER}->{SESSION}, 
-			$_[HEAP]->{ERRORHANDLER}->{EVENT}, 
+		POE::Kernel->post(
+			$_[HEAP]->{ERRORHANDLER}->{SESSION},
+			$_[HEAP]->{ERRORHANDLER}->{EVENT},
 			'BadRequest (by POE::Filter::HTTPD)', $response->connection->remote_ip()
 		);
 		$_[KERNEL]->yield('DONE', $response);
@@ -788,7 +807,7 @@ sub Got_Input {
 				croak("I had a problem posting to event $handler->{'EVENT'} of session $handler->{'SESSION'} for DIR handler '$handler->{'DIR'}'",
 			      	". As reported by Kernel: '$!', perhaps the session name is spelled incorrectly for this handler?")
                 	if $!;
-	
+
 				# All done!
 				return;
 			}
@@ -811,7 +830,7 @@ sub Got_Flush {
 	if ( DEBUG ) {
 		warn "Got Flush event for wheel ID ( $id )";
 	}
-	
+
    if ($_[HEAP]->{'REQUESTS'}->{ $id }->[1] == 2 ) {
 		# Do the stream !
 		if ( DEBUG ) {
@@ -826,7 +845,7 @@ sub Got_Flush {
             if ( DEBUG ) {
                 warn "Keep-alive id=$id ...";
             }
-            $_[HEAP]->{'CONNECTIONS'}->{ $id } = [ 
+            $_[HEAP]->{'CONNECTIONS'}->{ $id } = [
                       $_[HEAP]->{'REQUESTS'}->{ $id }->[0],   # wheel
                       $_[HEAP]->{'REQUESTS'}->{ $id }->[2]->connection
                     ];
@@ -912,7 +931,7 @@ sub Got_Error {
 	    	delete $_[HEAP]->{'REQUESTS'}->{ $id }->[0];
 	    	delete $_[HEAP]->{'REQUESTS'}->{ $id };
         }
-            
+
 		# Mark the client dead
 		$connection->{'DIED'} = 1;
 	}
@@ -945,7 +964,7 @@ sub Request_Output {
 		if ( DEBUG ) {
 			warn 'Wheel disappeared, but the application sent us a DONE event, discarding it';
 		}
-		
+
       POE::Kernel->post(
          $_[HEAP]->{ERRORHANDLER}->{SESSION},
          $_[HEAP]->{ERRORHANDLER}->{EVENT},
@@ -971,7 +990,7 @@ sub Request_Output {
          $_[HEAP]->{ERRORHANDLER}->{SESSION},
          $_[HEAP]->{ERRORHANDLER}->{EVENT},
          'Socket closed/nonexistant !'
-      ); 
+      );
 		return;
 	}
 
@@ -983,11 +1002,28 @@ sub Request_Output {
    # Mark this socket done
    $_[HEAP]->{'REQUESTS'}->{ $id }->[1] = 1;
 
+	# Log FINALLY If they have a logFinal handler registered, send out the needed information
+	$_[KERNEL]->call(
+		$_[HEAP]->{'LOG2HANDLER'}->{'SESSION'},
+		$_[HEAP]->{'LOG2HANDLER'}->{'EVENT'},
+		$_[HEAP]->{'REQUESTS'}{ $id }[3],
+		$response)
+	if $_[HEAP]->{'LOG2HANDLER'};
+
+	# Warn if we had a problem dispatching to the log handler above
+	warn("I had a problem posting to event '",
+		$_[HEAP]->{'LOG2HANDLER'}->{'EVENT'},
+		"' of the log handler alias '",
+		$_[HEAP]->{'LOG2HANDLER'}->{'SESSION'},
+		"'. As reported by Kernel: '$!', perhaps the alias is spelled incorrectly for this handler?")
+	if $!;
+
+
    # Debug stuff
    if ( DEBUG ) {
            warn "Completed with Wheel ID $id";
    }
-  
+
    # Success!
    return 1;
 }
@@ -995,24 +1031,24 @@ sub Request_Output {
 # Stream output to the client
 sub Stream_Output {
    # ARG0 = HTTP::Response object
-   my ($kernel, $response) = @_[KERNEL, ARG0 ];   
-   
+   my ($kernel, $response) = @_[KERNEL, ARG0 ];
+
    # Check if we got it
    if ( ! defined $response or ! UNIVERSAL::isa( $response, 'HTTP::Response' ) ) {
       if ( DEBUG ) {
          warn 'Did not get a HTTP::Response object!';
       }
-      
+
       # Abort...
       return undef;
    }
-   
+
    # Get the wheel ID
    my $id = $response->_WHEEL;
    $_[HEAP]->{'CHUNKCOUNT'}->{ $id }++;
 
    if (defined $response->{'STREAM'}) {
-      # Keep track if we plan to stream ...   	
+      # Keep track if we plan to stream ...
       if ( $_[HEAP]->{'RESPONSES'}->{ $id } ) {
          if ( DEBUG ) {
             warn "Restoring response from HEAP and id $id ";
@@ -1044,14 +1080,14 @@ sub Stream_Output {
          $_[HEAP]->{ERRORHANDLER}->{SESSION},
          $_[HEAP]->{ERRORHANDLER}->{EVENT},
          'Wheel disappeared !'
-      ); 
+      );
       # All done!
       return 1;
    }
-   
+
    # Quick check to see if the wheel/socket died already...
    # Initially reported by Tim Wood
-   if ( ! defined $_[HEAP]->{'REQUESTS'}->{ $id }->[0] 
+   if ( ! defined $_[HEAP]->{'REQUESTS'}->{ $id }->[0]
       or ! defined $_[HEAP]->{'REQUESTS'}->{ $id }->[0]->[ POE::Wheel::ReadWrite::HANDLE_INPUT ] ) {
       if ( DEBUG ) {
          warn 'Tried to send data over a closed/nonexistant socket!';
@@ -1060,14 +1096,14 @@ sub Stream_Output {
          $_[HEAP]->{ERRORHANDLER}->{SESSION},
          $_[HEAP]->{ERRORHANDLER}->{EVENT},
          'Socket closed/nonexistant !'
-      ); 
+      );
       return;
    }
-   
+
    Fix_Headers( $_[HEAP], $response, 1 );
 
    # Preliminary check
-   if ( ! defined $_[HEAP]->{'REQUESTS'}->{ $response->_WHEEL }->[0] 
+   if ( ! defined $_[HEAP]->{'REQUESTS'}->{ $response->_WHEEL }->[0]
       or ! defined $_[HEAP]->{'REQUESTS'}->{ $response->_WHEEL }->[0]->[ POE::Wheel::ReadWrite::HANDLE_INPUT ] ) {
       if ( DEBUG ) {
          warn 'Tried to send data over a closed/nonexistant socket!';
@@ -1079,14 +1115,14 @@ sub Stream_Output {
    unless (defined $response->{'IS_STREAMING'}) {
       # Mark this socket done
       $_[HEAP]->{'REQUESTS'}->{ $id }->[1] = 2;
-      
+
       #
       $response->{'IS_STREAMING'} = 1;
    }
-   
+
    if ( DEBUG ) {
       warn "Sending stream via ".$response->{STREAM_SESSION}."/".$response->{STREAM}." with id $id \n" ;
-   }      
+   }
 
    if ( $_[HEAP]->{'CHUNKCOUNT'}->{ $id } > 1  ) {
       $_[HEAP]->{'REQUESTS'}->{ $response->_WHEEL }->[0]->set_output_filter(POE::Filter::Stream->new() ) ;
@@ -1098,17 +1134,17 @@ sub Stream_Output {
    }
 
    $response->content();
-   
-   # we send the event to stream with wheels request and response to the session 
-   # that has registered the streaming event     
-   unless ($response->{'dont_flush'}) {          
+
+   # we send the event to stream with wheels request and response to the session
+   # that has registered the streaming event
+   unless ($response->{'DONT_FLUSH'}) {
       POE::Kernel->post(
          $response->{STREAM_SESSION},           # callback session
          $response->{STREAM},                   # callback event
          $_[HEAP]->{'RESPONSES'}->{$response->_WHEEL}
-      ); 
+      );
    }
-	
+
     # Success!
 	return 1;
 }
@@ -1121,7 +1157,7 @@ sub Fix_Headers
     if ( ! $response->header( 'Date' ) ) {
         $response->header( 'Date', time2str( time ) );
     }
-   
+
 	# Set the Content-Length if needed
 	if ( not $stream and not defined $response->header( 'Content-Length' )  ) {
 		use bytes;
@@ -1164,7 +1200,7 @@ sub Request_Close {
     if( $_[HEAP]->{'CONNECTIONS'}->{ $id } ) {
         my $c = delete $_[HEAP]->{'CONNECTIONS'}->{ $id };
         $_[HEAP]->{'REQUESTS'}->{ $id } = [ $c->[0], 0, undef ];
-    }        
+    }
 
 
 	# Check if the wheel exists ( sometimes it gets closed by the client, but the application doesn't know that... )
@@ -1201,11 +1237,11 @@ sub Request_Close {
 # Registers a POE inline state (primarly for streaming)
 sub Register {
    my ( $session , $state, $code_ref) = @_[SESSION, ARG0 .. ARG1];
-   
+
 	if ( DEBUG ) {
 		warn 'Registering state in POE session';
 	}
-   
+
    return $session->register_state( $state, $code_ref );
 }
 
@@ -1216,7 +1252,7 @@ sub SetCloseHandler
     my( $connection, $state, @params ) = @_[ ARG0..$#_ ];
 
     # turn connection ID into the connection object
-    unless( ref $connection ) {         
+    unless( ref $connection ) {
         my $id = $connection;
         if( $heap->{'CONNECTIONS'}->{$id} ) {
             $connection = $heap->{'CONNECTIONS'}->{$id}->[1];
@@ -1286,6 +1322,10 @@ POE::Component::Server::SimpleHTTP - Perl extension to serve HTTP requests in PO
 				  'EVENT'   => 'GOT_LOG',
 		},
 
+		'LOG2HANDLER' => { 'SESSION' => 'HTTP_GET',
+				  'EVENT'   => 'POSTLOG',
+		},
+
 		# In the testing phase...
 		'SSLKEYCERT'	=>	[ 'public-key.pem', 'public-cert.pem' ],
 	) or die 'Unable to create the HTTP Server';
@@ -1361,7 +1401,7 @@ POE::Component::Server::SimpleHTTP - Perl extension to serve HTTP requests in PO
 	}
 
 	sub GOT_LOG {
-		# ARG0 = HTTP::Request object, ARG1 = remote IP 
+		# ARG0 = HTTP::Request object, ARG1 = remote IP
 		my ($request, $remote_ip) = @_[ARG0,ARG1];
 
 		# Do some sort of logging activity.
@@ -1506,6 +1546,7 @@ EVENT	->	The event to trigger
 
 You will receive an event for each request to the server from clients.  Malformed client requests will not be passed into the handler.  Instead
 undef will be passed.
+Event is called before ANY content handler is called.
 
 The event will have the following parameters:
 
@@ -1513,6 +1554,33 @@ ARG0 -> HTTP::Request object/undef if client request was malformed.
 
 ARG1 -> the IP address of the client
 
+=item C<LOG2HANDLER>
+
+Expect a hashref with the following key, valyes:
+
+SESSION	->	The session to send the input
+
+EVENT	->	The event to trigger
+
+You will receive an event for each response that hit DONE call. Malformed client requests will not be passed into the handler.
+Event is after processing all content handlers.
+
+The event will have the following parameters:
+
+ARG0 -> HTTP::Request object
+
+ARG1 -> HTTP::Response object
+
+That makes possible following code:
+
+	my ($login, $password) = $request->authorization_basic();
+	printf STDERR "%s - %s [%s] \"%s %s %s\" %d %d\n",
+		$response->connection->remote_ip, $login||'-', POSIX::strftime("%d/%b/%Y:%T %z",localtime(time())),
+		$request->method(), $request->uri()->path(), $request->protocol(),
+		$response->code(), length($response->content());
+
+Emulate apache-like logs for PoCo::Server::SimpleHTTP
+
 =item C<SETUPHANDLER>
 
 Expects a hashref with the following key, values:
@@ -1532,6 +1600,11 @@ is greatly welcome!
 
 Again, this will automatically turn every incoming connection into a SSL socket. Once enough testing has been done, this option will be augmented with more SSL stuff!
 
+=item C<PROXYMODE>
+
+Set this to a true value to enable the server to act as a proxy server, ie. it won't mangle the HTTP::Request
+URI.
+
 =back
 
 =head2 Events
@@ -1576,11 +1649,11 @@ SimpleHTTP is so simple, there are only 8 events available.
 
 =item C<SETCLOSEHANDLER>
 
-    $_[KERNEL]->call( $_[SENDER], 'SETCLOSEHANDLER', $connection, 
+    $_[KERNEL]->call( $_[SENDER], 'SETCLOSEHANDLER', $connection,
                       $event, @args );
 
 Calls C<$event> in the current session when C<$connection> is closed.  You
-could use for persistent connection handling.  
+could use for persistent connection handling.
 
 Multiple session may register close handlers.
 
@@ -1616,15 +1689,15 @@ associated with this C<$connection>.
 
 	With a $response argument it streams the content and calls back the streaming event
 	of the user's session (or with the dont_flush option you're responsible for calling
-        back your session's streaming event).	
-	
+        back your session's streaming event).
+
 	To use the streaming feature see below.
 
 =back
 
 =head2 Streaming with SimpleHTTP
 
-It's possible to send data as a stream to clients (unbuffered and integrated in the 
+It's possible to send data as a stream to clients (unbuffered and integrated in the
 POE loop).
 
 Just create your session to receive events from SimpleHTTP as usually and add a
@@ -1638,7 +1711,7 @@ $response to a streaming state and once you trigger it:
       event       => 'GOT_STREAM',
       dont_flush  => 1
    );
-   
+
    # then you can simply yield your streaming event, once the GOT_STREAM event
    # has reached its end it will be triggered again and again, until you
    # send a CLOSE event to the kernel with the appropriate response as parameter
@@ -1653,10 +1726,10 @@ shutdown when your streaming is done (EOF for example).
 
    sub GOT_STREAM {
       my ( $kernel, $heap, $response ) = @_[KERNEL, HEAP, ARG0];
-      
+
       # sets the content of the response
       $response->content("Hello World\n");
-      
+
       # send it to the client
       POE::Kernel->post('HTTPD', 'STREAM', $response);
 
@@ -1676,7 +1749,7 @@ shutdown when your streaming is done (EOF for example).
    }
 
 The dont_flush option is there to be able to control the frequency of flushes
-to the client. 
+to the client.
 
 =head2 SimpleHTTP Notes
 
